@@ -7,7 +7,7 @@ import Data.Bits
 import Data.IORef
 
 myDomain = "example.com"
-smtpHost = "hubert.blacksapphire.com"    -- <-- Your SMTP server here
+smtpHost = "hubert"    -- <-- Your SMTP server here
 
 -- This will send the author an email.  I don't mind!
 main = do
@@ -15,7 +15,7 @@ main = do
     nowCT <- toCalendarTime now
     let message = Message [
                 From [NameAddr (Just "Mr. Nobody") "nobody@example.com"],
-                To   [NameAddr (Just "Stephen Blackheath") "unprintable.distances.stephen@blacksapphire.com"],
+                To   [NameAddr (Just "Stephen Blackheath") "maxine@hip-to-be-square.com"],
                 Subject "I'm using SMTPClient!",
                 Date nowCT
             ]
